Module esrt

Module esrt 

Get the ESRT UEFI table and extract the version information.

Currently only implemented on Linux and UEFI. I haven’t found how to get it on Windows.

ESRT (EFI System Resource Table) holds information about updateable firmware components in the system. It includes the current version, as well as if and how they can be updated via a UEFI capsule. Windows and LVFS take advantage of this information.

Not all firmware components are reported here.

Structs

Esrt
EsrtResourceEntry

Enums

FrameworkGuidKind
ResourceType
UpdateStatus

Constants

ADL_BIOS_GUID
ADL_RETIMER01_GUID
ADL_RETIMER23_GUID
AMD13_AI300_BIOS_GUID
AMD13_RYZEN7040_BIOS_GUID
AMD16_AI300_BIOS_GUID
DESKTOP_AMD_AI300_BIOS_GUID
ESRT_FIRMWARE_RESOURCE_VERSION
FL16_BIOS_GUID
FW12_RPL_BIOS_GUID
MTL_BIOS_GUID
MTL_CSME_GUID
MTL_RETIMER01_GUID
MTL_RETIMER23_GUID
RPL_BIOS_GUID
RPL_CSME_GUID
RPL_RETIMER01_GUID
RPL_RETIMER23_GUID
RPL_U_CSME_GUID
SYSTEM_RESOURCE_TABLE_GUID
gEfiSystemResourceTableGuid from MdePkg/MdePkg.dec
SYSTEM_RESOURCE_TABLE_GUID_BYTES
TGL_BIOS_GUID
TGL_RETIMER01_GUID
TGL_RETIMER23_GUID
WINUX_GUID
gWindowsUxCapsuleGuid from MdePkg/MdePkg.dec

Functions

get_esrt
match_guid_kind
print_esrt